==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythweb/modules/settings/mythweb.php <==
<?php
/**
 * Display/save mythweb default settings
 *
 * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/modules/settings/mythweb.php $
 * @date        $Date: 2006-06-24 15:03:10 -0400 (Sat, 24 Jun 2006) $
 * @version     $Revision: 10290 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Settings
 *
/**/

// Save?
    if ($_POST['save']) {
    // Some global mythweb settings
        $_SESSION['prefer_channum'] = setting('WebPrefer_Channum', null, $_POST['prefer_channum'] ? 1 : 0);
    // Video URL needs some special checking
        $_POST['video_url'] = trim($_POST['video_url']);
        if (empty($_POST['video_url']) || preg_match('#^\w+://#', $_POST['video_url']))
            setting('WebVideo_URL', null, $_POST['video_url']);
        else
            add_warning('Video URL needs a URI indicator like myth:// or file://');
    // Video artwork directory
        $_POST['video_artwork_dir'] = trim($_POST['video_artwork_dir']);
        if (!empty($_POST['video_artwork_dir'])) {
            if (!file_exists($_POST['video_artwork_dir']))
                add_error('Video artwork directory "'.$_POST['video_artwork_dir'].'" doesn\'t exist.');
            elseif (!is_dir($_POST['video_artwork_dir']) && !is_link($_POST['video_artwork_dir']))
                add_error('Video artwork directory "'.$_POST['video_artwork_dir'].'" exists but is not a directory.');
            else {
                setting('VideoArtworkDir', hostname, $_POST['video_artwork_dir']);
            }
        }
    // MythVideo directory
        $_POST['mythvideo_dir'] = trim($_POST['mythvideo_dir']);
        if (!empty($_POST['mythvideo_dir'])) {
            if (!file_exists($_POST['mythvideo_dir']))
                add_error('MythVideo directory "'.$_POST['mythvideo_dir'].'" doesn\'t exist.');
            elseif (!is_dir($_POST['mythvideo_dir']) && !is_link($_POST['mythvideo_dir']))
                add_error('MythVideo directory "'.$_POST['mythvideo_dir'].'" exists but is not a directory.');
            else {
                setting('VideoStartupDir', hostname, $_POST['mythvideo_dir']);
            }
        }
    }

// Load the class for this page
    require_once tmpl_dir.'mythweb.php';

// Exit
    exit;

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythweb/modules/settings/mythweb.php <==
<?php
/**
 * Display/save mythweb default settings
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/settings/mythweb.php $
 * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
 * @version     $Revision: 10290 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Settings
 *
/**/

// Save?
    if ($_POST['save']) {
    // Some global mythweb settings
        $_SESSION['prefer_channum'] = setting('WebPrefer_Channum', null, $_POST['prefer_channum'] ? 1 : 0);
    // Video URL needs some special checking
        $_POST['video_url'] = trim($_POST['video_url']);
        if (empty($_POST['video_url']) || preg_match('#^\w+://#', $_POST['video_url']))
            setting('WebVideo_URL', null, $_POST['video_url']);
        else
            add_warning('Video URL needs a URI indicator like myth:// or file://');
    // Video artwork directory
        $_POST['video_artwork_dir'] = trim($_POST['video_artwork_dir']);
        if (!empty($_POST['video_artwork_dir'])) {
            if (!file_exists($_POST['video_artwork_dir']))
                add_error('Video artwork directory "'.$_POST['video_artwork_dir'].'" doesn\'t exist.');
            elseif (!is_dir($_POST['video_artwork_dir']) && !is_link($_POST['video_artwork_dir']))
                add_error('Video artwork directory "'.$_POST['video_artwork_dir'].'" exists but is not a directory.');
            else {
                setting('VideoArtworkDir', hostname, $_POST['video_artwork_dir']);
            }
        }
    // MythVideo directory
        $_POST['mythvideo_dir'] = trim($_POST['mythvideo_dir']);
        if (!empty($_POST['mythvideo_dir'])) {
            if (!file_exists($_POST['mythvideo_dir']))
                add_error('MythVideo directory "'.$_POST['mythvideo_dir'].'" doesn\'t exist.');
            elseif (!is_dir($_POST['mythvideo_dir']) && !is_link($_POST['mythvideo_dir']))
                add_error('MythVideo directory "'.$_POST['mythvideo_dir'].'" exists but is not a directory.');
            else {
                setting('VideoStartupDir', hostname, $_POST['mythvideo_dir']);
            }
        }
    }

// Load the class for this page
    require_once tmpl_dir.'mythweb.php';

// Exit
    exit;
